#####
###  StructuredDocument - a Structured-Text-Document-Product for ZOPE
##   Copyright (C) 2002	Maik Jablonski (maik.jablonski@uni-bielefeld.de)
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
##   along with this program; if not, write to the Free Software
###  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#####

from Globals import HTML,DTMLFile, InitializeClass
from OFS.content_types import guess_content_type
from OFS.DTMLMethod import decapitate
from OFS.DTMLDocument import DTMLDocument
from AccessControl import getSecurityManager
from urllib import quote
import StructuredText

_marker=[]

standard_structured_document = """\
Structured Text - Introduction

 Structured text uses indentation and simple symbology
 to indicate the structure of a document.

 Elements of a Structured Text

  |-------------------------------------------|
  | A simple sample Table                     |
  |===========================================|
  | *emphasized* |  **strong** | _underlined_ |
  |-------------------------------------------|
  | "Link to ZOPE":http://www.zope.org/       |
  |-------------------------------------------|

  Text enclosed in brackets [footnote] is treated as 
  hyperlinks within the document.

  Three types of lists

   - Unordered lists with '-', '*', or 'o'

   1 Ordered lists with digits

   Description -- A paragraph with a first line that
   contains some text, followed by some white-space
   and '--' is treated as a descriptive list element.  

  Example code

   Sub-paragraphs of a paragraph that ends in '::' is treated as example code::
     
    <html>...</html>

.. [footnote] Here is the footnoote.
"""

def manage_addStructuredDocument(self, id, title='', file='', REQUEST=None, submit=None):
    """Add a Structured Text object with the contents of file. If
    'file' is empty, default document text is used.
    """
    if type(file) is not type(''): file=file.read()

    if not file:
    	if(hasattr(self,'standard_structured_document')):
		file=self.standard_structured_document.document_src()
	else:
		file=standard_structured_document
		
    id=str(id)
    title=str(title)
    ob=StructuredDocument(file, __name__=id)
    ob.title=title
    id=self._setObject(id, ob)
    if REQUEST is not None:
        try: u=self.DestinationURL()
        except: u=REQUEST['URL1']
        if submit==" Add and Edit ": u="%s/%s" % (u,quote(id))
        REQUEST.RESPONSE.redirect(u+'/manage_main')
    return ''
           
manage_addStructuredDocumentForm = DTMLFile('dtml/addStructuredDocument', globals())

class StructuredDocument(DTMLDocument):
    """ A DTMLDocument object that wraps Structured Text """

    meta_type = 'Structured Document'

    # Don't need Proxy-Roles for Structured Document,
    # so leave them out in the manage_tabs...
    
    manage_options=DTMLDocument.manage_options[:3]+DTMLDocument.manage_options[4:]
    
    def __call__(self, client=None, REQUEST={}, RESPONSE=None, **kw):
        """ Render the document given a client object, REQUEST mapping,
        Response, and key word arguments. """

	# original code from OFS/DTMLDocument.py

        if not self._cache_namespace_keys:
            data = self.ZCacheable_get(default=_marker)
            if data is not _marker:
                # Return cached results.
                return data

	# Here we go on our own...
	
	if client and hasattr(self,'standard_html_header') and hasattr(self,'standard_html_footer'):
		r = self.standard_html_header(self, REQUEST, RESPONSE)
		r = r + StructuredText.StructuredText.HTML(self.document_src(), header=0)
		r = r + self.standard_html_footer(self, REQUEST, RESPONSE)	
	else:
		r = StructuredText.StructuredText.HTML(self.document_src(), header=0)
		
	# original code from OFS/DTMLDocument.py again
	
        result = decapitate(r, RESPONSE)
        if not self._cache_namespace_keys:
            self.ZCacheable_set(result)
        return result

InitializeClass(StructuredDocument)
